@@ -1,6 +1,5 @@
 from bs4 import BeautifulSoup
 from colorama import Fore
-from tldextract import tldextract
 from yarl import URL
 
 from ..base_functions import log, logger, ssl_context
@@ -12,9 +11,7 @@ class AnonfilesCrawler():
         self.include_id = include_id
 
     async def fetch(self, session, url):
-        url_extract = tldextract.extract(str(url))
-        base_domain = "{}.{}".format(url_extract.domain, url_extract.suffix)
-        domain_obj = DomainItem(base_domain, {})
+        domain_obj = DomainItem(url.host, {})
 
         await log("Starting scrape of " + str(url), Fore.WHITE)
 
